pub struct Plutip { /* private fields */ }

Implementations

source

impl Plutip

source

pub async fn start(config: PlutipConfig) -> Result<Self, PlutipError>

Launching the Plutip local cluster Once the handler goes out of scope, the local cluster will be killed

source

pub async fn get_wallet( &self, wallet_idx: usize ) -> Result<KeyWallet, PlutipError>

Get a wallet by an index generated and funded by Plutip

source

pub async fn get_own_wallet(&self) -> Result<KeyWallet, PlutipError>

Get the first wallet generated and funded by Plutip

source

pub fn get_node_socket(&self) -> PathBuf

Get the path to the active cardano-node socket

source

pub fn get_network(&self) -> Network

Get the Cardano network discriminant

source

pub async fn get_node_config_path(&self) -> PathBuf

Get the path cardano-node configuration file

source

pub fn kill(&mut self) -> Result<(), Error>

Kill plutip process

source

pub fn cleanup(&mut self) -> Result<(), Error>

Cleanup all resources used by plutip