Struct tx_bakery_plutip::Plutip
source · pub struct Plutip { /* private fields */ }Implementations
sourceimpl Plutip
impl Plutip
sourcepub async fn start(config: PlutipConfig) -> Result<Self, PlutipError>
pub async fn start(config: PlutipConfig) -> Result<Self, PlutipError>
Launching the Plutip local cluster Once the handler goes out of scope, the local cluster will be killed
sourcepub async fn get_wallet(
&self,
wallet_idx: usize
) -> Result<KeyWallet, PlutipError>
pub async fn get_wallet( &self, wallet_idx: usize ) -> Result<KeyWallet, PlutipError>
Get a wallet by an index generated and funded by Plutip
sourcepub async fn get_own_wallet(&self) -> Result<KeyWallet, PlutipError>
pub async fn get_own_wallet(&self) -> Result<KeyWallet, PlutipError>
Get the first wallet generated and funded by Plutip
sourcepub fn get_node_socket(&self) -> PathBuf
pub fn get_node_socket(&self) -> PathBuf
Get the path to the active cardano-node socket
sourcepub fn get_network(&self) -> Network
pub fn get_network(&self) -> Network
Get the Cardano network discriminant
sourcepub async fn get_node_config_path(&self) -> PathBuf
pub async fn get_node_config_path(&self) -> PathBuf
Get the path cardano-node configuration file